from colab.plugins.views import ColabProxyView
from django.contrib.staticfiles.views import serve
from django.http import HttpResponse
from revproxy.transformer import DiazoTransformer
import os


class ColabMkdocsPluginProxyView(ColabProxyView):
    app_label = 'colab_mkdocs_tos'
    diazo_theme_template = 'proxy/mkdocs.html'

    def dispatch(self, request, path):
        dir_path = os.path.dirname(os.path.realpath(__file__))
        static_path = os.path.join(dir_path, 'static/mkdocs_build')
        docs_path = os.path.join(static_path, path)

        if os.path.isdir(docs_path):
            path = os.path.join(path, 'index.html')
        path = os.path.join('mkdocs_build', path)

        file_response = serve(request, path, insecure=True)
        response = HttpResponse(
            file_response.streaming_content,
            content_type=file_response.get('Content-type') + ';charset=utf-8')
        context_data = self.get_context_data()
        diazo = DiazoTransformer(request, response)

        response = diazo.transform(self.diazo_rules, self.diazo_theme_template,
                                   self.html5, context_data)
        return response



# -*- coding: utf-8 -*-

name = 'colab_mkdocs_tos'
verbose_name = 'Colab Mkdocs Plugin Plugin'

upstream = ''

docs_title = "Sobre"

pages = [
    ('Página Inicial', 'index.md'),
    ('Wikilegis', 'wikilegis.md'),
    ('Audiências Interativas', 'audiencias.md'),
    ('Expressão', 'expressao.md'),
    ('Termos de Serviço', 'tos.md'),
]


urls = {
    'include': 'colab_mkdocs_tos.urls',
    'prefix': '^sobre/',
}

settings_variables = {
    'COLAB_STATICS': [
        '/colab-plugins/tos/src/colab_mkdocs_tos/static'
    ]
}



from django.core.management.base import BaseCommand
from django.template.loader import render_to_string
from colab.plugins import helpers
import colab_mkdocs_tos
import os


class Command(BaseCommand):

    def handle(self, *args, **options):
        mkdocs_path = os.path.dirname(colab_mkdocs_tos.__file__)
        filename = os.path.join(mkdocs_path, 'mkdocs.yml')
        plugin_config = helpers.get_plugin_config('colab_mkdocs_tos')
        rendered = render_to_string('mkdocs.yml', {
            'mkdocs_title': plugin_config['docs_title'],
            'mkdocs_dir': mkdocs_path,
            'mkdocs_pages': plugin_config['pages']
        })

        with open(filename, 'w'):
            # Clean file
            pass

        with open(filename, 'w') as config_file:
            config_file.write(rendered.encode('utf8'))



#!/usr/bin/env python
"""
Colab Mkdocs Plugin
===================================
"""
from setuptools import setup, find_packages

install_requires = ['colab', 'mkdocs', 'mkdocs-material']

tests_require = ['mock']


setup(
    name="colab-mkdocs-tos",
    version='0.2.0',
    author='labhackercd',
    author_email='labhackercd@gmail.com',
    url='https://github.com/labhackercd/colab-mkdocs-plugin',
    description='Colab Mkdocs Plugin',
    long_description=__doc__,
    license='GPLv3',
    package_dir={'': 'src'},
    packages=find_packages('src'),
    zip_safe=False,
    install_requires=install_requires,
    test_suite="tests.runtests.run",
    tests_require=tests_require,
    extras_require={'test': tests_require},
    include_package_data=True,
    classifiers=[
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Operating System :: OS Independent',
        'Topic :: Software Development'
    ],
)
